@@ -1,7 +1,12 @@
-#! /usr/bin/python
+# -*- coding: utf-8 -*-
 
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
+
+import os.path
+import sys
+
+from . import Load, PyGrace
+from .ParamParser import *
 
 #
 #
@@ -11,13 +16,6 @@ from __future__ import absolute_import
 # Please visit www.gnu.org
 #
 
-import sys
-import os.path
-
-from . import PyGrace
-from . import Load
-from .ParamParser import *
-
 
 class MatrixPlotter(object):
 
