@@ -1,13 +1,11 @@
-#! /usr/bin/python
+# -*- coding: utf-8 -*-
 
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
+from __future__ import absolute_import, division, print_function
 
-from builtins import range
-from builtins import object
-from past.utils import old_div
 import math
+from builtins import object, range
+
+from past.utils import old_div
 
 
 class SPGHistogram(object):
